pub fn build_dc_opf_matrices(instance: &DcOpfInstance) -> DcOpfMatricesExpand description
Build sparse matrices without reading the source network again.
pub fn build_dc_opf_matrices(instance: &DcOpfInstance) -> DcOpfMatricesBuild sparse matrices without reading the source network again.