pub fn write_dcopf_bundle(
instance: &DcOpfInstance,
out_dir: impl AsRef<Path>,
options: &DcOpfBundleOptions,
) -> Result<DcOpfOutputs>Expand description
Write matrix projections for an assembled DC OPF instance.
The writer reads all costs, bounds, mappings, units, and conventions from
instance. It does not retain or read a source network.